import { createLibp2p } from "libp2p";
import { DirectSub } from "@dao-xyz/libp2p-direct-sub";
import { DirectBlock } from "@dao-xyz/libp2p-direct-block";
import { noise } from "@dao-xyz/libp2p-noise";
import { mplex } from "@libp2p/mplex";
import { transports, relay } from "./transports.js";
import { identifyService } from "libp2p/identify";
export const createLibp2pExtended = (opts = {
    services: {
        blocks: (c) => new DirectBlock(c),
        pubsub: (c) => new DirectSub(c),
    },
}) => {
    const relayIdentify = {
        relay: relay(),
        identify: identifyService(),
    };
    // https://github.com/libp2p/js-libp2p/issues/1757
    Object.keys(relayIdentify).forEach((key) => {
        if (relayIdentify[key] === undefined) {
            delete relayIdentify[key];
        }
    });
    return createLibp2p({
        connectionManager: {
            minConnections: 0,
        },
        addresses: {
            listen: ["/ip4/127.0.0.1/tcp/0", "/ip4/127.0.0.1/tcp/0/ws"],
        },
        transports: transports(),
        connectionEncryption: [noise()],
        streamMuxers: [mplex()],
        ...opts,
        services: {
            ...relayIdentify,
            pubsub: opts.services?.pubsub ||
                ((c) => new DirectSub(c, {
                    canRelayMessage: true,
                    signaturePolicy: "StrictNoSign",
                    connectionManager: {
                        autoDial: true,
                    },
                })),
            blocks: opts.services?.blocks || ((c) => new DirectBlock(c)),
            ...opts.services,
        },
    });
};
//# sourceMappingURL=index.js.map